def 断开数据库连接(连接对象, 游标对象):
    """
    断开与MySQL数据库的连接，关闭游标对象和连接对象。

    参数：
        - 连接对象：表示与数据库的连接。
        - 游标对象：用于执行查询和获取结果的游标对象。

    返回值：
        - 成功断开返回 True，失败返回 False。

    使用示例（可以复制并直接修改）：
        执行结果 = zfx_mysql.断开数据库连接(连接对象, 游标对象)

        # 替换参数：
        # - 连接对象：需要断开的数据库连接对象
        # - 游标对象：需要关闭的游标对象

        # if 执行结果:
        #     print("数据库连接成功断开")
        # else:
        #     print("断开连接失败")
    """
    try:
        # 关闭游标对象
        if 游标对象:
            游标对象.close()

        # 关闭数据库连接
        if 连接对象:
            连接对象.close()

        return True
    except Exception:
        return False